@@ -1,5 +1,6 @@
 /* wavbreaker - A tool to split a wave file up into multiple waves.
  * Copyright (C) 2002-2004 Timothy Robinson
+ * Copyright (C) 2007 Thomas Perl
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -116,6 +117,9 @@ static int ask_really_quit = 1;
 /* Show toolbar in main window */
 static int show_toolbar = 1;
 
+/* Draw moodbar in main window */
+static int show_moodbar = 1;
+
 /* function prototypes */
 static int appconfig_read_file();
 static void default_all_strings();
@@ -234,8 +238,13 @@ void set_audio_function_pointers()
         gtk_widget_hide( output_device_label);
         gtk_widget_hide( output_device_entry);
     } else {
-        gtk_widget_show( output_device_label);
-        gtk_widget_show( output_device_entry);
+        if( get_audio_driver_type() == ALSA) {
+            gtk_widget_hide( output_device_label);
+            gtk_widget_hide( output_device_entry);
+        } else {
+            gtk_widget_show( output_device_label);
+            gtk_widget_show( output_device_entry);
+        }
         gtk_entry_set_text(GTK_ENTRY(output_device_entry), audio_options_get_output_device());
     }
 }
@@ -288,7 +297,7 @@ void set_audio_alsa_options_output_device(const char *val) {
 }
 
 void default_audio_alsa_options_output_device() {
-    set_audio_alsa_options_output_device("plughw:0,0");
+    set_audio_alsa_options_output_device("default");
 }
 
 /* generic audio driver functions */
@@ -376,6 +385,15 @@ void appconfig_set_show_toolbar(int x)
     show_toolbar = x;
 }
 
+int appconfig_get_show_moodbar() {
+    return show_moodbar;
+}
+
+void appconfig_set_show_moodbar(int x)
+{
+    show_moodbar = x;
+}
+
 int get_use_outputdir()
 {
     return use_outputdir;
@@ -736,7 +754,7 @@ void appconfig_show(GtkWidget *main_window)
     gtk_combo_box_append_text(GTK_COMBO_BOX(combo_box), "OSS");
 #endif
 #ifdef HAVE_ALSA
-    gtk_combo_box_append_text(GTK_COMBO_BOX(combo_box), "ALSA (recommended)");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(combo_box), "ALSA");
 #endif
 #ifdef HAVE_JACK
     gtk_combo_box_append_text(GTK_COMBO_BOX(combo_box), "Jack");
@@ -860,10 +878,15 @@ static int appconfig_read_file() {
             key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
             set_audio_oss_options_output_device((char *)key);
             xmlFree(key);
+        /***
+         * Don't load ALSA output device config parameter (always use "default")
+         *
         } else if (!(xmlStrcmp(cur->name, (const xmlChar *) "alsa_options_output_device"))) {
             key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
             set_audio_alsa_options_output_device((char *)key);
             xmlFree(key);
+         *
+         ***/
         } else if (!(xmlStrcmp(cur->name, (const xmlChar *) "outputdir"))) {
             key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
             set_outputdir((char *)key);
@@ -924,6 +947,11 @@ static int appconfig_read_file() {
             nkey = atoi((char *)key);
             appconfig_set_show_toolbar(nkey);
             xmlFree(key);
+        } else if (!(xmlStrcmp(cur->name, (const xmlChar *) "show_moodbar"))) {
+            key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
+            nkey = atoi((char *)key);
+            appconfig_set_show_moodbar(nkey);
+            xmlFree(key);
         }
         cur = cur->next;
     }
@@ -1156,6 +1184,18 @@ int appconfig_write_file() {
         return 3;
     }
 
+    sprintf(tmp_str, "%d", appconfig_get_show_moodbar());
+    cur = xmlNewChild(root, NULL, (const xmlChar *)"show_moodbar",
+        (const xmlChar *) tmp_str);
+
+    if (cur == NULL) {
+        fprintf(stderr, "error creating wavbreaker config file\n");
+        fprintf(stderr, "error creating show_moodbar node\n");
+        xmlFreeNodeList(root);
+        xmlFreeDoc(doc);
+        return 3;
+    }
+
     root = xmlDocSetRootElement(doc, root);
     /*
     if (root == NULL) {
